@@ -14,7 +14,7 @@
 
 #define STUB_API "stub_mem.cc"
 #include "Mem.h"
-#include "STUB.h"
+#include "tests/STUB.h"
 
 void
 memFreeString(size_t size, void *buf)
